@@ -195,13 +195,13 @@ age.default <- function(x,method='U238-Pb206',exterr=TRUE,J=c(NA,NA),
 #' table with the following columns: \code{t.75}, \code{err[t.75]},
 #' \code{t.68}, \code{err[t.68]}, \code{t.76}, \code{err[t.76]},
 #' (\code{t.82}, \code{err[t.82]},) \code{t.conc}, \code{err[t.conc]},
-#' (\code{err[p.conc]},) containing the
+#' (\code{disc}) or \code{err[p.conc]},) containing the
 #' \eqn{^{207}}Pb/\eqn{^{235}}U-age and standard error, the
 #' \eqn{^{206}}Pb/\eqn{^{238}}U-age and standard error, the
 #' \eqn{^{207}}Pb/\eqn{^{206}}Pb-age and standard error, (the
 #' \eqn{^{208}}Pb/\eqn{^{232}}Th-age and standard error,) the single
-#' grain concordia age and standard error, (and the p-value for
-#' concordance,) respectively.
+#' grain concordia age and standard error, (and the \% discordance or
+#' p-value for concordance,) respectively.
 #'
 #' \item if \code{x} has class \code{UPb} and \code{type=2, 3, 4} or
 #' \code{5}, returns the output of the \code{\link{concordia}}
@@ -416,8 +416,18 @@ add.exterr <- function(x,tt,st,cutoff.76=1100,type=4){
     } else if (hasClass(x,'LuHf')){
         R <- get.LuHf.ratio(tt,st,exterr=FALSE)
         out <- get.LuHf.age(R[1],R[2],exterr=TRUE)
-    } else if (hasClass(x,'fissiontracks') & x$format<3){
-        out[2] <- tt * sqrt( (x$zeta[2]/x$zeta[1])^2 + (st/tt)^2 )
+    } else if (hasClass(x,'fissiontracks')){
+        if (x$format==1) {
+            rhoD <- x$rhoD
+            zeta <- x$zeta
+        } else if (x$format==2) {
+            rhoD <- c(1,0)
+            zeta <- x$zeta
+        } else {
+            rhoD <- c(1,0)
+            zeta <- c(1,0)
+        }
+        out[2] <- tt * sqrt( (st/tt)^2 + (rhoD[2]/rhoD[1])^2 + (zeta[2]/zeta[1])^2 )
     }
     out
 }
