@@ -355,14 +355,18 @@
 #'
 #' \item{y0}{a three or four-element vector containing:
 #'
-#' \code{y}: the initial \eqn{^{206}}Pb/\eqn{^{204}}U-ratio (if
+#' \code{y}: the initial \eqn{^{206}}Pb/\eqn{^{204}}Pb-ratio (if
 #' \code{type=1} and \code{x$format=4,5} or \code{6});
-#' \eqn{^{207}}Pb/\eqn{^{204}}U-ratio (if \code{type=2} and
+#' \eqn{^{207}}Pb/\eqn{^{204}}Pb-ratio (if \code{type=2} and
 #' \code{x$format=4,5} or \code{6});
-#' \eqn{^{208}}Pb/\eqn{^{206}}U-ratio (if \code{type=1} and
+#' \eqn{^{208}}Pb/\eqn{^{206}}Pb-ratio (if \code{type=1} and
+#' \code{x$format=7} or \code{8}); 
+#' \eqn{^{208}}Pb/\eqn{^{207}}Pb-ratio (if \code{type=2} and
+#' \code{x$format=7} or \code{8});
+#' \eqn{^{206}}Pb/\eqn{^{208}}Pb-ratio (if \code{type=3} and
 #' \code{x$format=7} or \code{8}); or
-#' \eqn{^{208}}Pb/\eqn{^{207}}U-ratio (if \code{type=2} and
-#' \code{x$format=7}).
+#' \eqn{^{207}}Pb/\eqn{^{208}}Pb-ratio (if \code{type=4} and
+#' \code{x$format=7} or \code{8}).
 #'
 #' \code{s[y]}: the propagated uncertainty of \code{y}
 #'
@@ -468,20 +472,15 @@ isochron.default <- function(x,alpha=0.05,sigdig=2,show.numbers=FALSE,
 }
 #' @param anchor
 #' control parameters to fix the intercept age or common Pb
-#' composition of the isochron fit. This is a two-element list.
+#' composition of the isochron fit. This can be a scalar or a vector.
 #'
-#' The first element is a boolean flag indicating whether the
-#' isochron line should be anchored. If this is \code{FALSE}, then
-#' the second item is ignored and both the common Pb composition and
-#' age are estimated.
+#' If \code{anchor[1]=0}: do not anchor the isochron.
 #'
-#' If the first element is \code{TRUE} and the second element is
-#' \code{NA}, then the common Pb composition is fixed at the values
+#' If \code{anchor[1]=1}: fix the common Pb composition at the values
 #' stored in \code{settings('iratio',...)}.
 #'
-#' If the first element is \code{TRUE} and the second element is
-#' a number, then the isochron line is forced to intersect the
-#' concordia line at an age equal to that number.
+#' If \code{anchor[1]=2}: force the isochron line to intersect the
+#' concordia line at an age equal to \code{anchor[2]}.
 #'
 #' @rdname isochron
 #' @export
@@ -491,9 +490,9 @@ isochron.UPb <- function(x,alpha=0.05,sigdig=2, show.numbers=FALSE,
                          ellipse.stroke='black',type=1,
                          ci.col='gray80',line.col='black',lwd=1,
                          plot=TRUE,exterr=FALSE,model=1,
-                         show.ellipses=1*(model!=2),
-                         anchor=list(FALSE,NA),hide=NULL,
-                         omit=NULL,omit.fill=NA,omit.stroke='grey',...){
+                         show.ellipses=1*(model!=2),anchor=0,
+                         hide=NULL, omit=NULL,omit.fill=NA,
+                         omit.stroke='grey',...){
     ns <- length(x)
     plotit <- (1:ns)%ni%hide
     calcit <- (1:ns)%ni%c(hide,omit)
@@ -894,8 +893,29 @@ isochron.LuHf <- function(x,alpha=0.05,sigdig=2, show.numbers=FALSE,
                 hide=hide,omit=omit,omit.fill=omit.fill,
                 omit.stroke=omit.stroke,...)
 }
-#' @param type following the classification of
-#' Ludwig and Titterington (1994), one of either:
+#' @param type
+#'
+#' if \code{x} has class \code{UPb} and \code{x$format=4}, \code{5} or 
+#' \code{6}:
+#'
+#' \code{1}: \eqn{^{204}}Pb/\eqn{^{206}}Pb vs. \eqn{^{238}}U/\eqn{^{206}}Pb
+#'
+#' \code{2}: \eqn{^{204}}Pb/\eqn{^{207}}Pb vs. \eqn{^{235}}U/\eqn{^{207}}Pb
+#'
+#' if \code{x} has class \code{UPb} and \code{x$format=7} or \code{8}:
+#'
+#' \code{1}: \eqn{^{208}}Pb\eqn{{}_\circ}/\eqn{^{206}}Pb vs. \eqn{^{238}}U/\eqn{^{206}}Pb
+#'
+#' \code{2}: \eqn{^{208}}Pb\eqn{{}_\circ}/\eqn{^{207}}Pb vs. \eqn{^{235}}U/\eqn{^{207}}Pb
+#' 
+#' \code{3}: \eqn{^{206}}Pb\eqn{{}_\circ}/\eqn{^{208}}Pb
+#' vs. \eqn{^{232}}Th/\eqn{^{208}}Pb
+#'
+#' \code{4}: \eqn{^{207}}Pb\eqn{{}_\circ}/\eqn{^{208}}Pb
+#' vs. \eqn{^{232}}Th/\eqn{^{208}}Pb
+#' 
+#' if \code{x} has class \code{ThU}, and following the classification
+#' of Ludwig and Titterington (1994), one of either:
 #'
 #' \code{1}: `Rosholt type-II' isochron, setting out
 #' \eqn{^{230}}Th/\eqn{^{232}}Th vs. \eqn{^{238}}U/\eqn{^{232}}Th
@@ -1037,7 +1057,7 @@ isochron_ThU_3D <- function(x,type=2,model=1,exterr=TRUE,
     out$y0['s[y]'] <- tst['s[48_0]']
     out$y0label <- quote('('^234*'U/'^238*'U)'[o]*'=')
     out <- ci_isochron(out,disp=FALSE)
-    if (model==1 && out$mswd>1){
+    if (inflate(out)){
         tdispt <- get.ThU.age(out$par[i08],
                               sqrt(out$mswd)*sqrt(out$cov[i08,i08]),
                               out$par[i48],
@@ -1076,7 +1096,7 @@ isochron_ThU_2D <- function(x,type=2,model=1,exterr=TRUE,
     out$y0[c('y','s[y]')] <-
         get.Th230Th232_0x(out$age['t'],Th230Th232[1],Th230Th232[2])
     out <- ci_isochron(out,disp=FALSE)
-    if (model==1 && out$mswd>1){
+    if (inflate(out)){
         out$age['disp[t]'] <-
             out$fact*get.ThU.age(Th230U238[1],
                                   sqrt(out$mswd)*Th230U238[2],
@@ -1268,7 +1288,7 @@ plot_PbPb_evolution <- function(from=0,to=4570,inverse=TRUE){
 }
 
 isochrontitle <- function(fit,sigdig=2,type=NA,units="Ma",...){
-    if (fit$model==1 && fit$mswd>1){
+    if (inflate(fit)){
         args1 <- quote(a%+-%b~'|'~c~'|'~d~u~'(n='*n*')')
         args2 <- quote(a%+-%b~'|'~c~'|'~d~u)
     } else {
@@ -1289,7 +1309,7 @@ isochrontitle <- function(fit,sigdig=2,type=NA,units="Ma",...){
                       b=intercept[2],
                       c=intercept[3],
                       u='')
-        if (fit$model==1 && fit$mswd>1){
+        if (inflate(fit)){
             list1$d <- slope[4]
             list2$d <- intercept[4]
         }
@@ -1306,7 +1326,7 @@ isochrontitle <- function(fit,sigdig=2,type=NA,units="Ma",...){
                       b=rounded.intercept[2],
                       c=rounded.intercept[3],
                       u='')
-        if (fit$model==1 && fit$mswd>1){
+        if (inflate(fit)){
             list1$d <- rounded.age[4]
             list2$d <- rounded.intercept[4]
         }
